ellipse_stats

Function ellipse_stats 

pub fn ellipse_stats(
    raw: &RawImage,
    p1: [f32; 2],
    p2: [f32; 2],
) -> Option<RoiStats>
Compute RoiStats over the ellipse inscribed in the rectangle spanned by p1 and p2 (in displayed-image-pixel coordinates).

Returns None when the bounding rectangle degenerates after clamping to the image bounds.